==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/constraintactivitiespreferredstartingtimesform.h <==
/***************************************************************************
                          constraintactivitiespreferredstartingtimes.h  -  description
                             -------------------
    begin                : 15 May 2004
    copyright            : (C) 2004 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H
#define CONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H

#include "ui_constraintactivitiespreferredstartingtimesform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintActivitiesPreferredStartingTimesForm : public QDialog, Ui::ConstraintActivitiesPreferredStartingTimesForm_template  {
	Q_OBJECT
public:
	TimeConstraintsList visibleConstraintsList;

	ConstraintActivitiesPreferredStartingTimesForm();
	~ConstraintActivitiesPreferredStartingTimesForm();
	
	void refreshConstraintsListBox();

	bool filterOk(TimeConstraint* ctr);

public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();
};

#endif

==> fet_5.28.6.orig.tar.bz2: fet-5.28.6/src/interface/constraintactivitiespreferredstartingtimesform.h <==
/***************************************************************************
                          constraintactivitiespreferredstartingtimes.h  -  description
                             -------------------
    begin                : 15 May 2004
    copyright            : (C) 2004 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H
#define CONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H

#include "ui_constraintactivitiespreferredstartingtimesform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintActivitiesPreferredStartingTimesForm : public QDialog, Ui::ConstraintActivitiesPreferredStartingTimesForm_template  {
	Q_OBJECT
public:
	TimeConstraintsList visibleConstraintsList;

	ConstraintActivitiesPreferredStartingTimesForm(QWidget* parent);
	~ConstraintActivitiesPreferredStartingTimesForm();
	
	void refreshConstraintsListWidget();

	bool filterOk(TimeConstraint* ctr);

public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();
};

#endif
